@@ -7,7 +7,7 @@ use JSON;
 use Colouring::In;
 use Image::Scale;
 use Cwd qw/abs_path/;
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 our (%TOOL, %MANIFEST_SCHEMA);
 BEGIN {
 	%TOOL = (
@@ -427,7 +427,7 @@ Progressive::Web::Application - Utility for making an application 'progressive'
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
@@ -442,7 +442,7 @@ Version 0.03
 		pathpart => 'payments',
 		manifest => {
 			name => 'Progressive Web Application Demo',
-			short_name => 'PWA Demo",
+			short_name => 'PWA Demo',
 			icons => '/root/static/images/icons',
 			start_url => '/',
 			display => 'standalone',
@@ -555,7 +555,7 @@ A Hash reference of params to build the web app manifest. See manifest_schema fo
 	Progressive::Web::Application->new(
 		manifest => {
 			name => 'Progressive Web Application Demo',
-			short_name => 'PWA Demo",
+			short_name => 'PWA Demo',
 			icons => '/root/static/images/icons',
 			start_url => '/',
 			display => 'standalone',
@@ -688,7 +688,7 @@ Set the manifest params see manifest_schema for full options.
 
 	$pwa->set_manifest(
 		name => 'Progressive Web Application Demo',
-		short_name => 'PWA Demo",
+		short_name => 'PWA Demo',
 		icons => '/root/static/images/icons',
 		start_url => '/',
 		display => 'standalone',
